__name__ = 'django-tags-input'
__version__ = '1.3'
__author__ = 'Rick van Hattem'
__author_email__ = 'Rick.van.Hattem@Fawo.nl'
__description__ = ('''Django jQuery Tags Input is a Django field and widget'''
    '''wrapper that uses `django-selectable for autocompletion''')
__url__ = 'https://github.com/WoLpH/django-tags-input'

