<input type="text" name="{{ name }}" id="{{ id }}" value="{{ values }}" autocomplete="off" />

<script type="text/javascript">
//<![CDATA[
jQuery(document).ready(function($){
    $('#{{ id }}').tagsInput({
        autocomplete: {
            selectFirst: true,
            autoFill: true,
            delay: 20
        },
        {% if not add_link %}addNew: false,{% endif %}
        minInputWidth: 145,
        height: '40px',
        width: '460px',
        autocomplete_url: '{{ autocomplete_url }}'
    });
{% block extra_script %}{% endblock %}
});
//]]>
</script>

{# django admin adds the help text. this is for use outside of the admin #}
{% block help %}{% if help_text %}<p class="help">{{help_text}}</p>{% endif %}{% endblock %}
{{ inline }}
